@@ -1024,11 +1024,12 @@ class Storage:
         db=None,
         cur=None,
     ) -> Iterable[Dict[str, Any]]:
-        for line in db.origin_visit_get_all(
+        lines = db.origin_visit_get_all(
             origin, last_visit=last_visit, limit=limit, cur=cur
-        ):
-            data = dict(zip(db.origin_visit_get_cols, line))
-            yield data
+        )
+        for line in lines:
+            visit = dict(zip(db.origin_visit_get_cols, line))
+            yield self._origin_visit_apply_update(visit, db)
 
     @timed
     @db_transaction(statement_timeout=500)
@@ -1037,7 +1038,7 @@ class Storage:
     ) -> Optional[Dict[str, Any]]:
         visit = db.origin_visit_find_by_date(origin, visit_date, cur=cur)
         if visit:
-            return visit
+            return self._origin_visit_apply_update(visit, db)
         return None
 
     @timed
@@ -1045,11 +1046,11 @@ class Storage:
     def origin_visit_get_by(
         self, origin: str, visit: int, db=None, cur=None
     ) -> Optional[Dict[str, Any]]:
-        ori_visit = db.origin_visit_get(origin, visit, cur)
-        if not ori_visit:
-            return None
-
-        return dict(zip(db.origin_visit_get_cols, ori_visit))
+        row = db.origin_visit_get(origin, visit, cur)
+        if row:
+            visit_dict = dict(zip(db.origin_visit_get_cols, row))
+            return self._origin_visit_apply_update(visit_dict, db)
+        return None
 
     @timed
     @db_transaction(statement_timeout=4000)
@@ -1061,14 +1062,15 @@ class Storage:
         db=None,
         cur=None,
     ) -> Optional[Dict[str, Any]]:
-        origin_visit = db.origin_visit_get_latest(
+        row = db.origin_visit_get_latest(
             origin,
             allowed_statuses=allowed_statuses,
             require_snapshot=require_snapshot,
             cur=cur,
         )
-        if origin_visit:
-            return dict(zip(db.origin_visit_get_cols, origin_visit))
+        if row:
+            visit = dict(zip(db.origin_visit_get_cols, row))
+            return self._origin_visit_apply_update(visit, db)
         return None
 
     @timed
@@ -1076,11 +1078,11 @@ class Storage:
     def origin_visit_get_random(
         self, type: str, db=None, cur=None
     ) -> Optional[Dict[str, Any]]:
-        result = db.origin_visit_get_random(type, cur)
-        if result:
-            return dict(zip(db.origin_visit_get_cols, result))
-        else:
-            return None
+        row = db.origin_visit_get_random(type, cur)
+        if row:
+            visit = dict(zip(db.origin_visit_get_cols, row))
+            return self._origin_visit_apply_update(visit, db)
+        return None
 
     @timed
     @db_transaction(statement_timeout=2000)
